@@ -25,12 +25,17 @@ NewTaskDialog::NewTaskDialog(QWidget *parent) :
 //    ui->timeEdit_2->setDateTime(QDateTime::currentDateTime());
     ui->complete->setVisible(false);
 
+    manager = new QNetworkAccessManager();
+    connect(manager, SIGNAL(finished(QNetworkReply*)),
+            this, SLOT(gReplyFinished(QNetworkReply*)));
+
     connect(this, SIGNAL(valid(bool)), this, SLOT(validAction(bool)));
 }
 
 NewTaskDialog::~NewTaskDialog()
 {
     delete ui;
+    delete manager;
 }
 
 void NewTaskDialog::setTodo(const QOrganizerTodo &todo1) {
@@ -45,8 +50,9 @@ void NewTaskDialog::setTodo(const QOrganizerTodo &todo1) {
     lat = desc.value(1);
     lng = desc.value(2);
     ui->radius->setText(desc.value(3));
+    ui->command->setText(desc.value(4));
     qDebug() << "desc size:" << desc.size();
-    if (desc.size() == 4)
+    if (desc.size() > 4)
         emit valid(true);
 
     ui->date->setChecked(true);
@@ -86,7 +92,8 @@ void NewTaskDialog::on_buttonBox_accepted1()
     else
         todo.setDueDateTime(QDateTime(QDate::currentDate().addDays(EXPIRE_AFTER_DAYS)));
 
-    QString desc = ui->location->toPlainText() + "\n" + lat + "\n" + lng + "\n" + ui->radius->toPlainText();
+    QString desc = ui->location->toPlainText() + "\n" + lat + "\n" + lng + "\n" + ui->radius->toPlainText()
+            + "\n" + ui->command->text();
     todo.setDescription(desc);
     if (ui->complete->isChecked())
         todo.setStatus(QOrganizerTodoProgress::StatusComplete);
@@ -141,6 +148,7 @@ void NewTaskDialog::gReplyFinished(QNetworkReply* reply) {
     //        return;
 
     //    xml.setDevice(&file);
+    xml.clear();
     xml.addData(reply->readAll());
     QString lat, lng, address;
     while (!xml.atEnd() && !xml.hasError())
@@ -164,13 +172,14 @@ void NewTaskDialog::gReplyFinished(QNetworkReply* reply) {
                 lat = xml.readElementText();
                 xml.readNextStartElement();
                 lng = xml.readElementText();
-                break;
+                break; // Use the first location match
             }
         }
     }
 
     //    file.close();
     qDebug() << lat << lng;
+    reply->deleteLater();
     if (xml.hasError())
     {
         qDebug() << "XML error: " << xml.errorString() << endl;
@@ -190,9 +199,6 @@ void NewTaskDialog::gReplyFinished(QNetworkReply* reply) {
 
 void NewTaskDialog::on_search_clicked()
 {
-    QNetworkAccessManager *manager = new QNetworkAccessManager();
-    connect(manager, SIGNAL(finished(QNetworkReply*)),
-            this, SLOT(gReplyFinished(QNetworkReply*)));
 
     QUrl url("http://maps.googleapis.com/maps/api/geocode/xml");
     url.addQueryItem("address", ui->location->toPlainText().replace(" ", "+"));
